@@ -1,10 +1,10 @@
 package Dancer::Plugin::MemcachedFast;
-{
-  $Dancer::Plugin::MemcachedFast::VERSION = '0.130500';
-}
+$Dancer::Plugin::MemcachedFast::VERSION = '0.150740';
 use strict;
 use warnings;
 
+# ABSTRACT: Dancer::Plugin::MemcachedFast - Cache things using Cache::Memcached::Fast
+
 use Dancer::Plugin;
 
 use Cache::Memcached::Fast;
@@ -13,7 +13,7 @@ my $default_timeout = 3600;
 my $ok_to_compress  = 0;
 my $cache           = do {
     my $config = plugin_setting;
-    $config->{servers} = [ $ENV{HAVE_TEST_MEMCACHED_SERVER_LOCALHOST} ]
+    $config->{servers} = [$ENV{HAVE_TEST_MEMCACHED_SERVER_LOCALHOST}]
         if exists $ENV{HAVE_TEST_MEMCACHED_SERVER_LOCALHOST};
     $default_timeout = delete $config->{default_timeout}
         if exists $config->{default_timeout};
@@ -31,42 +31,40 @@ register memcached_compress => sub {
         return;
     }
     $cache->compress(
-        !!$_[ 0 ]
+        !!$_[0]
         );
 };
 
 register memcached_get_or_set => sub {
-    $cache->get($_[ 0 ])
-        or do {
+    $cache->get($_[0]) or do {
         my $ret;
-        $cache->set($_[ 0 ],
-            $ret = ref $_[ 1 ] eq 'CODE' ? $_[ 1 ]->() : $_[ 1 ]);
+        $cache->set($_[0], $ret = ref $_[1] eq 'CODE' ? $_[1]->() : $_[1]);
         $ret;
         }
-        or $_[ 1 ];
+        or $_[1];
 };
 
 register memcached_get => sub {
-    return $cache->get($_[ 0 ]) if $#_ == 0 and !ref $_[ 0 ];
+    return $cache->get($_[0]) if $#_ == 0 and !ref $_[0];
     $cache->get_multi(map {ref $_ and ref $_ eq 'ARRAY' ? @$_ : $_} @_);
 };
 
 register memcached_gets => sub {
-    return $cache->gets($_[ 0 ]) if $#_ == 0 and !ref $_[ 0 ];
+    return $cache->gets($_[0]) if $#_ == 0 and !ref $_[0];
     $cache->gets_multi(map {ref $_ and ref $_ eq 'ARRAY' ? @$_ : $_} @_);
 };
 
 register memcached_set => sub {
     return $cache->set(
-        $_[ 0 ],
-        ref $_[ 1 ] eq 'CODE' ? $_[ 1 ]->() : $_[ 1 ],
-        defined $_[ 2 ] ? $_[ 2 ] : $default_timeout
-    ) if ref $_[ 0 ] ne 'ARRAY';
+        $_[0],
+        ref $_[1] eq 'CODE' ? $_[1]->() : $_[1],
+        defined $_[2]       ? $_[2]     : $default_timeout
+    ) if ref $_[0] ne 'ARRAY';
     $cache->set_multi(
         map {[
-                $_->[ 0 ],
-                ref $_->[ 1 ] eq 'CODE' ? $_->[ 1 ]->() : $_->[ 1 ],
-                defined $_->[ 2 ] ? $_->[ 2 ] : $default_timeout
+                $_->[0],
+                ref $_->[1] eq 'CODE' ? $_->[1]->() : $_->[1],
+                defined $_->[2]       ? $_->[2]     : $default_timeout
             ]
         } grep {ref $_ eq 'ARRAY'} @_
     );
@@ -74,15 +72,15 @@ register memcached_set => sub {
 
 register memcached_add => sub {
     return $cache->add(
-        $_[ 0 ],
-        ref $_[ 1 ] eq 'CODE' ? $_[ 1 ]->() : $_[ 1 ],
-        defined $_[ 2 ] ? $_[ 2 ] : $default_timeout
-    ) if ref $_[ 0 ] ne 'ARRAY';
+        $_[0],
+        ref $_[1] eq 'CODE' ? $_[1]->() : $_[1],
+        defined $_[2]       ? $_[2]     : $default_timeout
+    ) if ref $_[0] ne 'ARRAY';
     $cache->add_multi(
         map {[
-                $_->[ 0 ],
-                ref $_->[ 1 ] eq 'CODE' ? $_->[ 1 ]->() : $_->[ 1 ],
-                defined $_->[ 2 ] ? $_->[ 2 ] : $default_timeout
+                $_->[0],
+                ref $_->[1] eq 'CODE' ? $_->[1]->() : $_->[1],
+                defined $_->[2]       ? $_->[2]     : $default_timeout
             ]
         } grep {ref $_ eq 'ARRAY'} @_
     );
@@ -90,55 +88,50 @@ register memcached_add => sub {
 
 register memcached_replace => sub {
     return $cache->replace(
-        $_[ 0 ],
-        ref $_[ 1 ] eq 'CODE' ? $_[ 1 ]->() : $_[ 1 ],
-        defined $_[ 2 ] ? $_[ 2 ] : $default_timeout
-    ) if ref $_[ 0 ] ne 'ARRAY';
+        $_[0],
+        ref $_[1] eq 'CODE' ? $_[1]->() : $_[1],
+        defined $_[2]       ? $_[2]     : $default_timeout
+    ) if ref $_[0] ne 'ARRAY';
     $cache->replace_multi(
         map {[
-                $_->[ 0 ],
-                ref $_->[ 1 ] eq 'CODE' ? $_->[ 1 ]->() : $_->[ 1 ],
-                defined $_->[ 2 ] ? $_->[ 2 ] : $default_timeout
+                $_->[0],
+                ref $_->[1] eq 'CODE' ? $_->[1]->() : $_->[1],
+                defined $_->[2]       ? $_->[2]     : $default_timeout
             ]
         } grep {ref $_ eq 'ARRAY'} @_
     );
 };
 
 register memcached_delete => sub {
-    return $cache->delete($_[ 0 ])
-        if $#_ == 0 and !ref $_[ 0 ];
+    return $cache->delete($_[0]) if $#_ == 0 and !ref $_[0];
     $cache->delete_multi(
         map {(ref $_ and ref $_ eq 'ARRAY') ? @$_ : $_} @_
         );
 };
 
 register memcached_append => sub {
-    return $cache->append(@_)
-        if ($#_ == 1 and !ref $_[ 0 ] and !ref $_[ 1 ]);
+    return $cache->append(@_) if ($#_ == 1 and !ref $_[0] and !ref $_[1]);
     $cache->append_multi(
         grep {ref $_ eq 'ARRAY'} @_
         );
 };
 
 register memcached_prepend => sub {
-    return $cache->prepend(@_)
-        if ($#_ == 1 and !ref $_[ 0 ] and !ref $_[ 1 ]);
+    return $cache->prepend(@_) if ($#_ == 1 and !ref $_[0] and !ref $_[1]);
     $cache->prepend_multi(
         grep {ref $_ eq 'ARRAY'} @_
         );
 };
 
 register memcached_incr => sub {
-    return $cache->incr(@_)
-        if ($#_ <= 2 and scalar grep {!ref $_} @_);
+    return $cache->incr(@_) if ($#_ <= 2 and scalar grep {!ref $_} @_);
     $cache->incr_multi(
         grep {ref $_ eq 'ARRAY'} @_
         );
 };
 
 register memcached_decr => sub {
-    return $cache->decr(@_)
-        if ($#_ <= 2 and scalar grep {!ref $_} @_);
+    return $cache->decr(@_) if ($#_ <= 2 and scalar grep {!ref $_} @_);
     $cache->decr_multi(
         grep {ref $_ eq 'ARRAY'} @_
         );
@@ -163,7 +156,7 @@ register memcached_disconnect_all => sub {
 
 register memcached_namespace => sub {
     $cache->namespace(
-        $_[ 0 ]
+        $_[0]
         );
 };
 
@@ -265,6 +258,11 @@ In your app:
         template 'meaning' => { meaning => $meaning };
     };
 
+=head1 DESCRIPTION
+
+This plugin allows Dancer to use L<Cache::Memcached::Fast> to get and store content
+on a number of memcached servers.
+
 =head1 TIMEOUTS
 
 You can set the default timeout via the configuration, as explained in the
@@ -402,3 +400,15 @@ returns the old value.
     # $current_prefix eq $old_prefix
     $current_prefix = memcached_namespace;
     # $current_prefix eq 'test:'
+
+=head1 CONTRIBUTORS
+
+Nikolay Mishin <mi@ya.ru>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2011 by Marco FONTANI.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
